@@ -2,7 +2,6 @@
 #include <gtkmm/window.h>
 #include <gtkmm/application.h>
 
-
 void
 win (TicTacToe *ttt)
 {
@@ -10,19 +9,26 @@ win (TicTacToe *ttt)
   ttt->clear();
 }
 
+class MyWindow : public Gtk::Window
+{
+public:
+  MyWindow();
+};
+
+MyWindow::MyWindow()
+{
+  set_title("Tic-Tac-Toe");
+
+  auto ttt = Gtk::make_managed<TicTacToe>();
+  ttt->tictactoe.connect(sigc::bind (sigc::ptr_fun(&win), ttt));
+  ttt->set_margin(10);
+  set_child(*ttt);
+}
 
 int
-main (int argc, char *argv[])
+main(int argc, char* argv[])
 {
   auto app = Gtk::Application::create("org.gtkmm.example");
 
-  auto ttt = Gtk::make_managed<TicTacToe>();
-  ttt->tictactoe.connect( sigc::bind (sigc::ptr_fun(&win), ttt) );
-
-  Gtk::Window window;
-  window.set_title("Tic-Tac-Toe");
-  ttt->set_margin(10);
-  window.add(*ttt);
-
-  return app->run(window, argc, argv);
+  return app->make_window_and_run<MyWindow>(argc, argv);
 }
